==> onekit-0.6.0.tar.gz: onekit-0.6.0/README.md <==
<p align="center">
<img src="https://raw.githubusercontent.com/estripling/onekit/main/docs/source/_static/onekitlogo.png" width="180" alt="onekit logo.">
</p>

<p align="center">
<a href="https://github.com/estripling/onekit"><img alt="pypi" src="https://img.shields.io/badge/github-code-blue"></a>
<a href="https://pypi.org/project/onekit"><img alt="pypi" src="https://img.shields.io/pypi/v/onekit"></a>
<a href="https://readthedocs.org/projects/onekit/?badge=latest"><img alt="docs" src="https://readthedocs.org/projects/onekit/badge/?version=latest"></a>
<a href="https://github.com/estripling/onekit/actions/workflows/test.yml"><img alt="test" src="https://github.com/estripling/onekit/actions/workflows/test.yml/badge.svg?branch=main"></a>
<a href="https://codecov.io/gh/estripling/onekit"><img alt="coverage" src="https://codecov.io/github/estripling/onekit/coverage.svg?branch=main"></a>
<a href="https://github.com/estripling/onekit/blob/main/LICENSE"><img alt="license" src="https://img.shields.io/pypi/l/onekit"></a>
</p>

## About

One package for utility functions:

- [Documentation](https://onekit.readthedocs.io/en/stable/index.html)
- [Developer Guide](https://onekit.readthedocs.io/en/stable/developers.html)
- [Examples](https://onekit.readthedocs.io/en/stable/example.html)
- [API Reference](https://onekit.readthedocs.io/en/stable/autoapi/index.html)

## Installation

`onekit` is available on [PyPI](https://pypi.org/project/onekit/) for Python 3.8+:

```console
pip install onekit
```

## License

`onekit` was created by onekit developers.
It is licensed under the terms of the BSD 3-Clause license.

==> onekit-0.10.0.tar.gz: onekit-0.10.0/README.md <==
<p align="center">
<img src="https://raw.githubusercontent.com/estripling/onekit/main/docs/source/_static/onekitlogo.png" width="180" alt="onekit logo.">
</p>

<p align="center">
<a href="https://github.com/estripling/onekit"><img alt="pypi" src="https://img.shields.io/badge/github-code-blue"></a>
<a href="https://pypi.org/project/onekit"><img alt="pypi" src="https://img.shields.io/pypi/v/onekit"></a>
<a href="https://readthedocs.org/projects/onekit/?badge=latest"><img alt="docs" src="https://readthedocs.org/projects/onekit/badge/?version=latest"></a>
<a href="https://github.com/estripling/onekit/actions/workflows/test.yml"><img alt="test" src="https://github.com/estripling/onekit/actions/workflows/test.yml/badge.svg?branch=main"></a>
<a href="https://codecov.io/gh/estripling/onekit"><img alt="coverage" src="https://codecov.io/github/estripling/onekit/coverage.svg?branch=main"></a>
<a href="https://github.com/estripling/onekit/blob/main/LICENSE"><img alt="license" src="https://img.shields.io/pypi/l/onekit"></a>
</p>

## About

One package for utility functions:

- [Examples](https://onekit.readthedocs.io/en/stable/examples.html)
- [Documentation](https://onekit.readthedocs.io/en/stable/index.html)
- [Developer Guide](https://onekit.readthedocs.io/en/stable/developers.html)
- [API Reference](https://onekit.readthedocs.io/en/stable/autoapi/index.html)

## Installation

`onekit` is available on [PyPI](https://pypi.org/project/onekit/) for Python 3.8+:

```console
pip install onekit
```

## License

`onekit` was created by onekit developers.
It is licensed under the terms of the BSD 3-Clause license.
